@@ -1,13 +1,18 @@
 """
-Demonstrates how to use the Tornado compatible scheduler to schedule a job that executes on 3 second intervals.
+Demonstrates how to use the Tornado compatible scheduler to schedule a job that executes on 3
+second intervals.
 """
 
 from datetime import datetime
-import asyncio
 import os
 
 from apscheduler.schedulers.asyncio import AsyncIOScheduler
 
+try:
+    import asyncio
+except ImportError:
+    import trollius as asyncio
+
 
 def tick():
     print('Tick! The time is: %s' % datetime.now())
