@@ -64,8 +64,11 @@ def test_remove(job):
 
 
 def test_pending(job):
-    """Tests that the "pending" property return True when _jobstore_alias is a string, False otherwise."""
+    """
+    Tests that the "pending" property return True when _jobstore_alias is a string, ``False``
+    otherwise.
 
+    """
     assert job.pending
 
     job._jobstore_alias = 'test'
@@ -75,7 +78,8 @@ def test_pending(job):
 def test_get_run_times(create_job, timezone):
     run_time = timezone.localize(datetime(2010, 12, 13, 0, 8))
     expected_times = [run_time + timedelta(seconds=1), run_time + timedelta(seconds=2)]
-    job = create_job(trigger='interval', trigger_args={'seconds': 1, 'timezone': timezone, 'start_date': run_time},
+    job = create_job(trigger='interval',
+                     trigger_args={'seconds': 1, 'timezone': timezone, 'start_date': run_time},
                      next_run_time=expected_times[0], func=dummyfunc)
 
     run_times = job._get_run_times(run_time)
@@ -90,7 +94,6 @@ def test_get_run_times(create_job, timezone):
 
 def test_private_modify_bad_id(job):
     """Tests that only strings are accepted for job IDs."""
-
     del job.id
     exc = pytest.raises(TypeError, job._modify, id=3)
     assert str(exc.value) == 'id must be a nonempty string'
@@ -98,21 +101,18 @@ def test_private_modify_bad_id(job):
 
 def test_private_modify_id(job):
     """Tests that the job ID can't be changed."""
-
     exc = pytest.raises(ValueError, job._modify, id='alternate')
     assert str(exc.value) == 'The job ID may not be changed'
 
 
 def test_private_modify_bad_func(job):
     """Tests that given a func of something else than a callable or string raises a TypeError."""
-
     exc = pytest.raises(TypeError, job._modify, func=1)
     assert str(exc.value) == 'func must be a callable or a textual reference to one'
 
 
 def test_private_modify_func_ref(job):
     """Tests that the target callable can be given as a textual reference."""
-
     job._modify(func='tests.test_job:dummyfunc')
     assert job.func is dummyfunc
     assert job.func_ref == 'tests.test_job:dummyfunc'
@@ -120,8 +120,9 @@ def test_private_modify_func_ref(job):
 
 def test_private_modify_unreachable_func(job):
     """Tests that func_ref remains None if no reference to the target callable can be found."""
+    def func():
+        pass
 
-    func = lambda: None
     job._modify(func=func)
     assert job.func is func
     assert job.func_ref is None
@@ -129,30 +130,29 @@ def test_private_modify_unreachable_func(job):
 
 def test_private_modify_update_name(job):
     """Tests that the name attribute defaults to the function name."""
-
     del job.name
     job._modify(func=dummyfunc)
     assert job.name == 'dummyfunc'
 
 
 def test_private_modify_bad_args(job):
-    """Tests that passing an argument list of the wrong type raises a TypeError."""
-
+    """ Tests that passing an argument list of the wrong type raises a TypeError."""
     exc = pytest.raises(TypeError, job._modify, args=1)
     assert str(exc.value) == 'args must be a non-string iterable'
 
 
 def test_private_modify_bad_kwargs(job):
     """Tests that passing an argument list of the wrong type raises a TypeError."""
-
     exc = pytest.raises(TypeError, job._modify, kwargs=1)
     assert str(exc.value) == 'kwargs must be a dict-like object'
 
 
 @pytest.mark.parametrize('value', [1, ''], ids=['integer', 'empty string'])
 def test_private_modify_bad_name(job, value):
-    """Tests that passing an empty name or a name of something else than a string raises a TypeError."""
+    """
+    Tests that passing an empty name or a name of something else than a string raises a TypeError.
 
+    """
     exc = pytest.raises(TypeError, job._modify, name=value)
     assert str(exc.value) == 'name must be a nonempty string'
 
@@ -160,7 +160,6 @@ def test_private_modify_bad_name(job, value):
 @pytest.mark.parametrize('value', ['foo', 0, -1], ids=['string', 'zero', 'negative'])
 def test_private_modify_bad_misfire_grace_time(job, value):
     """Tests that passing a misfire_grace_time of the wrong type raises a TypeError."""
-
     exc = pytest.raises(TypeError, job._modify, misfire_grace_time=value)
     assert str(exc.value) == 'misfire_grace_time must be either None or a positive integer'
 
@@ -168,52 +167,50 @@ def test_private_modify_bad_misfire_grace_time(job, value):
 @pytest.mark.parametrize('value', [None, 'foo', 0, -1], ids=['None', 'string', 'zero', 'negative'])
 def test_private_modify_bad_max_instances(job, value):
     """Tests that passing a max_instances of the wrong type raises a TypeError."""
-
     exc = pytest.raises(TypeError, job._modify, max_instances=value)
     assert str(exc.value) == 'max_instances must be a positive integer'
 
 
 def test_private_modify_bad_trigger(job):
     """Tests that passing a trigger of the wrong type raises a TypeError."""
-
     exc = pytest.raises(TypeError, job._modify, trigger='foo')
     assert str(exc.value) == 'Expected a trigger instance, got str instead'
 
 
 def test_private_modify_bad_executor(job):
     """Tests that passing an executor of the wrong type raises a TypeError."""
-
     exc = pytest.raises(TypeError, job._modify, executor=1)
     assert str(exc.value) == 'executor must be a string'
 
 
 def test_private_modify_bad_next_run_time(job):
     """Tests that passing a next_run_time of the wrong type raises a TypeError."""
-
     exc = pytest.raises(TypeError, job._modify, next_run_time=1)
     assert str(exc.value) == 'Unsupported type for next_run_time: int'
 
 
 def test_private_modify_bad_argument(job):
     """Tests that passing an unmodifiable argument type raises an AttributeError."""
-
     exc = pytest.raises(AttributeError, job._modify, scheduler=1)
     assert str(exc.value) == 'The following are not modifiable attributes of Job: scheduler'
 
 
 def test_getstate(job):
     state = job.__getstate__()
-    assert state == dict(version=1, trigger=job.trigger, executor='default', func='tests.test_job:dummyfunc',
-                         name=b'n\xc3\xa4m\xc3\xa9'.decode('utf-8'), args=(), kwargs={},
-                         id=b't\xc3\xa9st\xc3\xafd'.decode('utf-8'), misfire_grace_time=1, coalesce=False,
-                         max_instances=1, next_run_time=None)
+    assert state == dict(
+        version=1, trigger=job.trigger, executor='default', func='tests.test_job:dummyfunc',
+        name=b'n\xc3\xa4m\xc3\xa9'.decode('utf-8'), args=(), kwargs={},
+        id=b't\xc3\xa9st\xc3\xafd'.decode('utf-8'), misfire_grace_time=1, coalesce=False,
+        max_instances=1, next_run_time=None)
 
 
 def test_setstate(job, timezone):
     trigger = DateTrigger('2010-12-14 13:05:00', timezone)
-    state = dict(version=1, scheduler=MagicMock(), jobstore=MagicMock(), trigger=trigger, executor='dummyexecutor',
-                 func='tests.test_job:dummyfunc', name='testjob.dummyfunc', args=[], kwargs={}, id='other_id',
-                 misfire_grace_time=2, coalesce=True, max_instances=2, next_run_time=None)
+    state = dict(
+        version=1, scheduler=MagicMock(), jobstore=MagicMock(), trigger=trigger,
+        executor='dummyexecutor', func='tests.test_job:dummyfunc', name='testjob.dummyfunc',
+        args=[], kwargs={}, id='other_id', misfire_grace_time=2, coalesce=True, max_instances=2,
+        next_run_time=None)
     job.__setstate__(state)
     assert job.id == 'other_id'
     assert job.func == dummyfunc
@@ -231,7 +228,6 @@ def test_setstate(job, timezone):
 
 def test_setstate_bad_version(job):
     """Tests that __setstate__ rejects state of higher version that it was designed to handle."""
-
     exc = pytest.raises(ValueError, job.__setstate__, {'version': 9999})
     assert 'Job has version 9999, but only version' in str(exc.value)
 
@@ -249,7 +245,8 @@ def test_repr(job):
     if six.PY2:
         assert repr(job) == '<Job (id=t\\xe9st\\xefd name=n\\xe4m\\xe9)>'
     else:
-        assert repr(job) == b'<Job (id=t\xc3\xa9st\xc3\xafd name=n\xc3\xa4m\xc3\xa9)>'.decode('utf-8')
+        assert repr(job) == \
+            b'<Job (id=t\xc3\xa9st\xc3\xafd name=n\xc3\xa4m\xc3\xa9)>'.decode('utf-8')
 
 
 @pytest.mark.parametrize('status, expected_status', [
