@@ -1,5 +1,4 @@
 from datetime import datetime
-import os
 
 import pytest
 
@@ -19,64 +18,73 @@ def dummy_job3():
     pass
 
 
-@pytest.fixture
-def memjobstore(request):
-    return MemoryJobStore()
+@pytest.yield_fixture
+def memjobstore():
+    yield MemoryJobStore()
 
 
-@pytest.fixture
-def sqlalchemyjobstore(request):
-    def finish():
-        store.shutdown()
-        if os.path.exists('apscheduler_unittest.sqlite'):
-            os.remove('apscheduler_unittest.sqlite')
-
+@pytest.yield_fixture
+def sqlalchemyjobstore(tmpdir):
+    db_path = tmpdir.join('apscheduler_unittest.sqlite')
     sqlalchemy = pytest.importorskip('apscheduler.jobstores.sqlalchemy')
-    store = sqlalchemy.SQLAlchemyJobStore(url='sqlite:///apscheduler_unittest.sqlite')
-    request.addfinalizer(finish)
-    return store
+    store = sqlalchemy.SQLAlchemyJobStore(url='sqlite:///%s' % db_path)
+    store.start(None, 'sqlalchemy')
+    yield store
+    store.shutdown()
+    db_path.remove()
 
 
-@pytest.fixture
-def mongodbjobstore(request):
-    def finish():
-        store.client.drop_database(store.collection.database.name)
-        store.shutdown()
+@pytest.yield_fixture
+def rethinkdbjobstore():
+    rethinkdb = pytest.importorskip('apscheduler.jobstores.rethinkdb')
+    store = rethinkdb.RethinkDBJobStore(database='apscheduler_unittest')
+    store.start(None, 'rethinkdb')
+    yield store
+    rethinkdb.r.db_drop('apscheduler_unittest').run(store.conn)
+    store.shutdown()
 
+
+@pytest.yield_fixture
+def mongodbjobstore():
     mongodb = pytest.importorskip('apscheduler.jobstores.mongodb')
     store = mongodb.MongoDBJobStore(database='apscheduler_unittest')
-    request.addfinalizer(finish)
-    return store
+    store.start(None, 'mongodb')
+    yield store
+    store.client.drop_database(store.collection.database.name)
+    store.shutdown()
 
 
-@pytest.fixture
-def redisjobstore(request):
-    def finish():
-        store.remove_all_jobs()
-        store.shutdown()
-
+@pytest.yield_fixture
+def redisjobstore():
     redis = pytest.importorskip('apscheduler.jobstores.redis')
     store = redis.RedisJobStore()
-    request.addfinalizer(finish)
-    return store
+    store.start(None, 'redis')
+    yield store
+    store.remove_all_jobs()
+    store.shutdown()
 
 
-@pytest.fixture(params=[memjobstore, sqlalchemyjobstore, mongodbjobstore, redisjobstore],
-                ids=['memory', 'sqlalchemy', 'mongodb', 'redis'])
+@pytest.fixture(params=[
+    'memjobstore', 'sqlalchemyjobstore', 'mongodbjobstore', 'redisjobstore', 'rethinkdbjobstore'
+], ids=['memory', 'sqlalchemy', 'mongodb', 'redis', 'rethinkdb'])
 def jobstore(request):
-    return request.param(request)
+    return request.getfuncargvalue(request.param)
 
 
-@pytest.fixture(params=[sqlalchemyjobstore, mongodbjobstore, redisjobstore], ids=['sqlalchemy', 'mongodb', 'redis'])
+@pytest.fixture(params=[
+    'sqlalchemyjobstore', 'mongodbjobstore', 'redisjobstore', 'rethinkdbjobstore'
+], ids=['sqlalchemy', 'mongodb', 'redis', 'rethinkdb'])
 def persistent_jobstore(request):
-    return request.param(request)
+    return request.getfuncargvalue(request.param)
 
 
 @pytest.fixture
 def create_add_job(timezone, create_job):
-    def create(jobstore, func=dummy_job, run_date=datetime(2999, 1, 1), id=None, paused=False, **kwargs):
+    def create(jobstore, func=dummy_job, run_date=datetime(2999, 1, 1), id=None, paused=False,
+               **kwargs):
         run_date = timezone.localize(run_date)
-        job = create_job(func=func, trigger='date', trigger_args={'run_date': run_date}, id=id, **kwargs)
+        job = create_job(func=func, trigger='date', trigger_args={'run_date': run_date}, id=id,
+                         **kwargs)
         job.next_run_time = None if paused else job.trigger.get_next_fire_time(None, run_date)
         if jobstore:
             jobstore.add_job(job)
@@ -133,13 +141,15 @@ def test_get_next_run_time(jobstore, create_add_job, timezone):
 
 def test_add_job_conflicting_id(jobstore, create_add_job):
     create_add_job(jobstore, dummy_job, datetime(2016, 5, 3), id='blah')
-    pytest.raises(ConflictingIdError, create_add_job, jobstore, dummy_job2, datetime(2014, 2, 26), id='blah')
+    pytest.raises(ConflictingIdError, create_add_job, jobstore, dummy_job2, datetime(2014, 2, 26),
+                  id='blah')
 
 
 def test_update_job(jobstore, create_add_job, timezone):
     job1 = create_add_job(jobstore, dummy_job, datetime(2016, 5, 3))
     job2 = create_add_job(jobstore, dummy_job2, datetime(2014, 2, 26))
-    replacement = create_add_job(None, dummy_job, datetime(2016, 5, 4), id=job1.id, max_instances=6)
+    replacement = create_add_job(None, dummy_job, datetime(2016, 5, 4), id=job1.id,
+                                 max_instances=6)
     assert replacement.max_instances == 6
     jobstore.update_job(replacement)
 
@@ -169,11 +179,12 @@ def test_update_job_next_runtime(jobstore, create_add_job, next_run_time, timezo
 @pytest.mark.parametrize('index', [0, 1, 2], ids=['first', 'middle', 'last'])
 def test_update_job_clear_next_runtime(jobstore, create_add_job, next_run_time, timezone, index):
     """
-    Tests that update_job() maintains the proper ordering of the jobs, even when their next run times are initially the
-    same.
-    """
+    Tests that update_job() maintains the proper ordering of the jobs,
+    even when their next run times are initially the same.
 
-    jobs = [create_add_job(jobstore, dummy_job, datetime(2014, 2, 26), 'job%d' % i) for i in range(3)]
+    """
+    jobs = [create_add_job(jobstore, dummy_job, datetime(2014, 2, 26), 'job%d' % i) for
+            i in range(3)]
     jobs[index].next_run_time = timezone.localize(next_run_time) if next_run_time else None
     jobstore.update_job(jobs[index])
     due_date = timezone.localize(datetime(2014, 2, 27))
@@ -247,11 +258,11 @@ def test_repr_memjobstore(memjobstore):
 
 
 def test_repr_sqlalchemyjobstore(sqlalchemyjobstore):
-    assert repr(sqlalchemyjobstore) == '<SQLAlchemyJobStore (url=sqlite:///apscheduler_unittest.sqlite)>'
+    assert repr(sqlalchemyjobstore).startswith('<SQLAlchemyJobStore (url=')
 
 
 def test_repr_mongodbjobstore(mongodbjobstore):
-    assert repr(mongodbjobstore) == "<MongoDBJobStore (client=MongoClient('localhost', 27017))>"
+    assert repr(mongodbjobstore).startswith("<MongoDBJobStore (client=MongoClient(")
 
 
 def test_repr_redisjobstore(redisjobstore):
